@@ -1,8 +1,9 @@
+#' @importFrom utils getParseData getSrcref tail
 impute_srcref <- function(x, parent_ref) {
   if (!is_conditional_or_loop(x)) return(NULL)
   if (is.null(parent_ref)) return(NULL)
 
-  pd <- utils::getParseData(parent_ref, includeText = FALSE)
+  pd <- get_tokens(parent_ref)
   pd_expr <-
     pd$line1 == parent_ref[[7L]] &
     pd$col1 == parent_ref[[2L]] &
@@ -67,11 +68,9 @@ impute_srcref <- function(x, parent_ref) {
     },
 
     "switch" = {
-      c(list(NULL),
-        list(make_srcref(3)),
-        Map(make_srcref,
-          from = seq(7, NROW(pd_child), 4))
-        )
+      exprs <- which(pd_child$token == "expr")
+      exprs <- exprs[exprs >= 3]
+      c(list(NULL), Map(make_srcref, from = exprs))
     },
 
     NULL
@@ -79,3 +78,28 @@ impute_srcref <- function(x, parent_ref) {
 }
 
 is_conditional_or_loop <- function(x) is.symbol(x[[1L]]) && as.character(x[[1L]]) %in% c("if", "for", "else", "switch")
+
+package_parse_data <- new.env()
+
+get_parse_data <- function(srcfile) {
+  if (length(package_parse_data) == 0) {
+    lines <- getSrcLines(srcfile, 1L, Inf)
+    res <- lapply(split_on_line_directives(lines),
+      function(x) getParseData(parse(text = x, keep.source = TRUE), includeText = FALSE))
+    for (i in seq_along(res)) {
+      package_parse_data[[names(res)[[i]]]] <- res[[i]]
+    }
+  }
+  package_parse_data[[srcfile[["filename"]]]]
+}
+
+clean_parse_data <- function() {
+  for (nme in ls(package_parse_data)) {
+    rm(nme, envir = package_parse_data)
+  }
+}
+
+# Needed to work around https://bugs.r-project.org/bugzilla3/show_bug.cgi?id=16756
+get_tokens <- function(srcref) {
+  getParseData(srcref) %||% get_parse_data(attr(getSrcref(srcref), "srcfile"))
+}
